---
name: Bug report
about: Create a report to help us improve
title: "[BUG] <Brief description>"
labels: ''
assignees: ''

---

**Describe the bug**
PLEASE FILL THIS FORM OUT ENTIRELY for a response. 

Is this a bug or a question? Questions and tech support inquiries should be directed to the "Discussions" section where your question may already be answered. If it's a bug, provide a clear and concise description of what the bug is here. 

**To Reproduce**
Steps to reproduce the behavior:
1. Go to '...'
2. Click on '....'
3. Scroll down to '....'
4. See error

**Expected behavior**
A clear and concise description of what you expected to happen.

**Screenshots**
If applicable, add screenshots to help explain your problem.

**Platform (please complete the following information):**
 - Hardware: [e.g. Raspberry Pi 3, Windows PC, Macbook M1] 
 - OS: [e.g. Raspberry Pi OS, OSX]
 - OS version: [e.g. Raspberry pi Debian Bullseye 64-bit / 32-bit]
 - Browser [e.g. chrome, safari]
 - Version [e.g. 22]

**Additional context**
Add any other context about the problem here.
